#######################################################################
#################### HEADER, CHANGE VALUES HERE #######################
#######################################################################
read_sets="readref.fasta   readsnp.fasta " # FOR instance: "read_set1.fa.gz read_set2.fq.gz"
prefix="test_ref" # all temp and final files will be written will start with this prefix
k=31 # size of kmers, 27 is a good value
c=4 # minimal coverage
d=1 # estimated number of error per read (used by kissreads only)
g=10000000 # estimated genome size. Used only to control kissnp2 memory usage. e.g. 3 billion (3000000000) uses 4Gb of RAM.
#######################################################################
#################### END HEADER                 #######################
#######################################################################



######### CHECK THE k PARITY ##########
rest=$(( $k % 2 ))
if [ $rest -eq 0 ]
then
echo "k=$k is even number, to avoid palindromes, we set it to $(($k-1))"
k=$(($k-1))
fi
#######################################


#######################################################################
#################### KISSNP2                    #######################
#######################################################################
./kissnp2_tool/kissnp2 $read_sets -t -k $k -c $c  -g $g -o $prefix # see also options for kissnp (filtration with max occurrence numbers (-C), filtration with respect to size of contig (-e), ...)

if [ $? -ne 0 ]
then
    echo "there was a problem with kissnp2, command line: ./kissnp2_exe $read_sets -t -k $k -c $c  -g $g -o $prefix"
    exit
fi


#######################################################################
#################### KISSREADS                  #######################
#######################################################################
smallk=$(($k-4)) # avoid to modify this.
i=5 #avoid modidy this
./kissreads/kissreads $prefix\_k_$k\_c_$c.fa $read_sets -k $smallk -c $c -d $d -n -i $i -o $prefix\_k_$k\_c_$c\_coherent -u $prefix\_k_$k\_c_$c\_uncoherent #no need to see kissreads option in theory.
if [ $? -ne 0 ]
then
echo "there was a problem with kissnp2, command line: ./kissreads_exe $prefix\_k_$k\_c_$c.fa $read_sets -k $smallk -c $c -d $d -n -i $i -o $prefix\_k_$k\_c_$c\_coherent -u $prefix\_k_$k\_c_$c\_uncoherent"
exit
fi

#######################################################################
#################### SORT AND FORMAT COHERENT RESULTS #################
#######################################################################
sort -rg $prefix\_k_$k\_c_$c\_coherent | cut -d " " -f 2 | tr ';' '\n' > $prefix\_k_$k\_c_$c\_coherent.fa
if [ $? -ne 0 ]
then
echo "there was a problem with the result sorting, command line: sort -rg $prefix\_k_$k\_c_$c\_coherent | cut -d " " -f 2 | tr ';' '\n' > $prefix\_k_$k\_c_$c\_coherent.fa"
exit
fi

echo "read2SNP done, coherent SNPs are stored in \""$prefix\_k_$k\_c_$c\_coherent.fa"\""
echo "Thanks for using read2snps - http://http://colibread.inria.fr/read2snps/"


#/Users/grizk/gassst  -d test_k_31_c_4_coherent.fa  -i /Users/grizk/kissnp2/kissnp2_tool/snp_list_readsnp  -p 100 -w 15 -m 8 -l 0 -r 1 -o temp;

